@@ -1,6 +1,6 @@
 package App::bif::OptArgs;
 
-our $VERSION = '0.1.5_1';
+our $VERSION = '0.1.5_2';
 
 package    # do a little hiding
   App::bif;
@@ -741,6 +741,12 @@ opt year => (
     comment => 'generate a yearly timesheet',
 );
 
+opt rollup => (
+    isa     => 'Bool',
+    alias   => 'r',
+    comment => 'roll times up into parent project(s)',
+);
+
 # ------------------------------------------------------------------------
 # bif show change
 # ------------------------------------------------------------------------
@@ -1568,7 +1574,7 @@ App::bif::OptArgs - bif command argument & option definitions
 
 =head1 VERSION
 
-0.1.5_1 (2015-06-26)
+0.1.5_2 (2015-06-26)
 
 =head1 SYNOPSIS
 
