@@ -11,7 +11,7 @@ use Time::Duration qw/ago/;
 use Time::Piece;
 use Time::Seconds;
 
-our $VERSION = '0.1.5_1';
+our $VERSION = '0.1.5_2';
 extends 'App::bif';
 
 sub run {
@@ -181,7 +181,7 @@ sub run_by_time {
         on         => 't.id = cd.action_topic_id_1',
         left_join  => 'task_status ts',
         on         => 'ts.id = t.task_status_id',
-        order_by   => [ 'c.mtime DESC', 'c.id DESC' ],
+        order_by   => [ 'mdate DESC', 'c.mtime ASC', 'c.id DESC' ],
     );
 
     $sth->execute;
@@ -207,26 +207,31 @@ sub run_by_time {
             $mdate = $n->[4];
             if ( $mdate eq $today ) {
                 $table->head(
-                    $dark . 'ID',
-                    'Who', $n->[4], 'Action [today]' . $reset,
+                    $dark . $n->[4],
+                    'Who',
+                    'Action [today]',
+                    'CID' . $reset,
                 );
             }
             elsif ( $mdate eq $yesterday ) {
                 $table->head(
-                    $dark . 'ID',
-                    'Who', $n->[4], 'Action [yesterday]' . $reset,
+                    $dark . $n->[4],
+                    'Who',
+                    'Action [yesterday]',
+                    'CID' . $reset
                 );
             }
             else {
                 $table->head(
-                    $dark . 'ID',
-                    'Who', $n->[4],
-                    'Action [' . ago( $n->[5], 1 ) . ']' . $reset,
+                    $dark . $n->[4],
+                    'Who',
+                    'Action [' . ago( $n->[5], 1 ) . ']',
+                    'CID' . $reset,
                 );
             }
         }
 
-        $table->row( $n->[1], $n->[2], $n->[0], $n->[3] );
+        $table->row( $n->[0], $n->[2], $n->[3], $n->[1] );
     }
 
     print $table->render . "\n";
@@ -493,7 +498,7 @@ bif-log - review the repository or topic history
 
 =head1 VERSION
 
-0.1.5_1 (2015-06-26)
+0.1.5_2 (2015-06-26)
 
 =head1 SYNOPSIS
 
