@@ -7,7 +7,7 @@ use DBIx::ThinSQL qw/ sq /;
 use Time::Piece;
 use Time::Seconds;
 
-our $VERSION = '0.1.5_1';
+our $VERSION = '0.1.5_2';
 extends 'App::bif';
 
 sub _build {
@@ -20,7 +20,7 @@ sub _build {
 
     my $i = 1;
     foreach my $item (@_) {
-        my ( $type, $start, $delta ) = @{$item};
+        my ( $type, $start, $delta, $rollup ) = @{$item};
         my $end;
 
         if ( $type eq 'year' ) {
@@ -83,8 +83,17 @@ sub _build {
                 },
                 inner_join => 'work_deltas wd',
                 on         => 'wd.change_id = c.id',
-                inner_join => 'projects p',
-                on         => 'p.id = wd.topic_id',
+                $rollup
+                ? (
+                    inner_join => 'projects_tree pt',
+                    on         => 'pt.child = wd.topic_id',
+                    inner_join => 'projects p',
+                    on         => 'p.id = pt.parent',
+                  )
+                : (
+                    inner_join => 'projects p',
+                    on         => 'p.id = wd.topic_id',
+                ),
                 inner_join => 'topics t',
                 on         => 't.id = p.id',
             ]
@@ -128,33 +137,37 @@ sub run {
     if ( $opts->{year} ) {
         $opts->{number} ||= 4;
         ( $col, $select, $format, $header ) =
-          _build( map { [ 'year', $dt, -( $opts->{number} - $_ ) ] }
+          _build(
+            map { [ 'year', $dt, -( $opts->{number} - $_ ), $opts->{rollup} ] }
               1 .. $opts->{number} );
     }
     elsif ( $opts->{month} ) {
         $opts->{number} ||= 4;
-        ( $col, $select, $format, $header ) =
-          _build( map { [ 'month', $dt, -( $opts->{number} - $_ ) ] }
-              1 .. $opts->{number} );
+        ( $col, $select, $format, $header ) = _build(
+            map { [ 'month', $dt, -( $opts->{number} - $_ ), $opts->{rollup} ] }
+              1 .. $opts->{number}
+        );
     }
     elsif ( $opts->{week} ) {
         $opts->{number} ||= 4;
         ( $col, $select, $format, $header ) =
-          _build( map { [ 'week', $dt, -( $opts->{number} - $_ ) ] }
+          _build(
+            map { [ 'week', $dt, -( $opts->{number} - $_ ), $opts->{rollup} ] }
               1 .. $opts->{number} );
     }
     elsif ( $opts->{day} ) {
         $opts->{number} ||= 3;
         ( $col, $select, $format, $header ) =
-          _build( map { [ 'day', $dt, -( $opts->{number} - $_ ) ] }
+          _build(
+            map { [ 'day', $dt, -( $opts->{number} - $_ ), $opts->{rollup} ] }
               1 .. $opts->{number} );
     }
     else {
         ( $col, $select, $format, $header ) = _build(
-            [ 'year',  $dt, 0 ],
-            [ 'month', $dt, 0 ],
-            [ 'week',  $dt, 0 ],
-            [ 'day',   $dt, 0 ],
+            [ 'day',   $dt, 0, $opts->{rollup} ],
+            [ 'week',  $dt, 0, $opts->{rollup} ],
+            [ 'month', $dt, 0, $opts->{rollup} ],
+            [ 'year',  $dt, 0, $opts->{rollup} ],
         );
     }
 
@@ -207,7 +220,7 @@ bif-show-timesheet - display time worked per project
 
 =head1 VERSION
 
-0.1.5_1 (2015-06-26)
+0.1.5_2 (2015-06-26)
 
 =head1 SYNOPSIS
 
@@ -239,6 +252,10 @@ Display multiple monthly timesheets. The default number is 4.
 
 Display NUMBER time periods instead of the default.
 
+=item --rollup, -r
+
+Roll times worked into the parent project(s) for accumulative values.
+
 =item --week, -w
 
 Display multiple weekly timesheets. The default number is 4.
