@@ -7,7 +7,7 @@ use Coro;
 use Log::Any '$log';
 use JSON;
 
-our $VERSION = '0.1.5_1';
+our $VERSION = '0.1.5_2';
 
 has changes_dup => (
     is      => 'rw',
@@ -84,7 +84,7 @@ sub new_temp_table {
 sub read {
     my $self = shift;
 
-    my $json = $self->rh->readline("\n\n");
+    my $json = $self->rh->readline("\015");
 
     if ( !defined $json ) {
         $self->on_error->('connection close/timeout');
@@ -115,7 +115,7 @@ sub write {
 
     $log->debugf( 'w: %s', \@_ );
 
-    return $self->wh->print( $self->json->encode( \@_ ) . "\n\n" );
+    return $self->wh->print( $self->json->encode( \@_ ) . "\015" );
 }
 
 # Let sub classes override if necessary
